==> aliyun_python_sdk_ecs-4.24.28-py2.py3-none-any.whl: aliyunsdkecs/request/v20140526/ModifyDiagnosticMetricSetRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkecs.endpoint import endpoint_data

class ModifyDiagnosticMetricSetRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Ecs', '2014-05-26', 'ModifyDiagnosticMetricSet')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_MetricIdss(self): # RepeatList
		return self.get_query_params().get('MetricIds')

	def set_MetricIdss(self, MetricIds):  # RepeatList
		for depth1 in range(len(MetricIds)):
			self.add_query_param('MetricIds.' + str(depth1 + 1), MetricIds[depth1])
	def get_MetricSetId(self): # String
		return self.get_query_params().get('MetricSetId')

	def set_MetricSetId(self, MetricSetId):  # String
		self.add_query_param('MetricSetId', MetricSetId)
	def get_Description(self): # String
		return self.get_query_params().get('Description')

	def set_Description(self, Description):  # String
		self.add_query_param('Description', Description)
	def get_MetricSetName(self): # String
		return self.get_query_params().get('MetricSetName')

	def set_MetricSetName(self, MetricSetName):  # String
		self.add_query_param('MetricSetName', MetricSetName)
	def get_ResourceType(self): # String
		return self.get_query_params().get('ResourceType')

	def set_ResourceType(self, ResourceType):  # String
		self.add_query_param('ResourceType', ResourceType)

==> aliyun_python_sdk_ecs-4.24.75-py2.py3-none-any.whl: aliyunsdkecs/request/v20140526/ModifyDiagnosticMetricSetRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkecs.endpoint import endpoint_data

class ModifyDiagnosticMetricSetRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Ecs', '2014-05-26', 'ModifyDiagnosticMetricSet','ecs')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_MetricIdss(self): # RepeatList
		return self.get_query_params().get('MetricIds')

	def set_MetricIdss(self, MetricIds):  # RepeatList
		for depth1 in range(len(MetricIds)):
			self.add_query_param('MetricIds.' + str(depth1 + 1), MetricIds[depth1])
	def get_MetricSetId(self): # String
		return self.get_query_params().get('MetricSetId')

	def set_MetricSetId(self, MetricSetId):  # String
		self.add_query_param('MetricSetId', MetricSetId)
	def get_Description(self): # String
		return self.get_query_params().get('Description')

	def set_Description(self, Description):  # String
		self.add_query_param('Description', Description)
	def get_MetricSetName(self): # String
		return self.get_query_params().get('MetricSetName')

	def set_MetricSetName(self, MetricSetName):  # String
		self.add_query_param('MetricSetName', MetricSetName)
	def get_ResourceType(self): # String
		return self.get_query_params().get('ResourceType')

	def set_ResourceType(self, ResourceType):  # String
		self.add_query_param('ResourceType', ResourceType)
